@@ -64,8 +64,12 @@ class Note {
 
     QString getCryptoPassword() const;
 
+    QString getFileChecksum() const;
+
     void setCryptoKey(const qint64 cryptoKey);
 
+    void setFileChecksum(const QString &checksum);
+
     static bool addNote(const QString &name, const QString &fileName, const QString &text);
 
     static Note fetch(int id);
@@ -108,7 +112,8 @@ class Note {
 
     bool storeNewText(QString text);
 
-    bool storeNoteTextFileToDisk(bool &currentNoteTextChanged);
+    bool storeNoteTextFileToDisk(bool &currentNoteTextChanged,
+                                 bool *wasCancelledDueToExternalModification = nullptr);
     bool storeNoteTextFileToDisk();
 
     static QString defaultNoteFileExtension();
@@ -167,6 +172,12 @@ class Note {
 
     static qint64 qint64Hash(const QString &str);
 
+    static QString calculateChecksum(const QString &text);
+
+    static void getChecksumStats(qint64 &totalTime, int &callCount);
+
+    static void resetChecksumStats();
+
     QString encryptNoteText();
 
     QString fetchDecryptedNoteText() const;
@@ -285,7 +296,7 @@ class Note {
 
     QString getInsertAttachmentMarkdown(QFile *file, QString title = QString(),
                                         bool returnUrlOnly = false,
-                                        QString fileBaseName = QString()) const;
+                                        QString fileName = QString()) const;
 
     static bool scaleDownImageFileIfNeeded(QFile &file);
 
@@ -391,6 +402,14 @@ class Note {
 
     QHash<Note, QSet<LinkHit>> findReverseLinkNotes();
 
+    [[nodiscard]] QString getDecryptedNoteText(const QString &encryptedNoteText) const;
+
+    static QString parseEncryptedNoteText(const QString &noteText);
+
+    QString getNextcloudFileLink() const;
+
+    QString getNextcloudNotesLink() const;
+
    protected:
     int _id;
     int _noteSubFolderId;
@@ -402,6 +421,7 @@ class Note {
     QString _decryptedNoteText;
     QString _cryptoPassword;
     QString _shareUrl;
+    QString _fileChecksum;
     QDateTime _fileCreated;
     QDateTime _fileLastModified;
     QDateTime _created;
