@@ -21,7 +21,6 @@
 #include <QPair>
 #include <QPlainTextEdit>
 #include <QRegularExpression>
-#include <QSettings>
 #include <QString>
 #include <QStringList>
 #include <QSyntaxHighlighter>
@@ -32,6 +31,8 @@
 #include <string>
 #include <utility>
 
+#include "services/settingsservice.h"
+
 #endif
 
 #endif    // QOWNNOTES_PCH_H
