@@ -33,11 +33,13 @@
 #include <QPlainTextEdit>
 #include <QProcess>
 #include <QPushButton>
+#include <QStyleFactory>
 #include <QTextBlock>
 #include <QTextCursor>
 #include <QTreeWidgetItem>
 #include <QVBoxLayout>
 
+#include "helpers/nomenuiconstyle.h"
 #include "services/settingsservice.h"
 
 #define ORDER_ASCENDING 0     // Qt::AscendingOrder // = 0
@@ -80,7 +82,7 @@ void Utils::Gui::searchForTextInTreeWidget(QTreeWidget *treeWidget, const QStrin
         treeWidget->findItems("", Qt::MatchContains | Qt::MatchRecursive);
 
     // search text if at least one character was entered
-    if (text.count() >= 1) {
+    if (text.size() >= 1) {
         int searchColumnCount =
             searchFlags & TreeWidgetSearchFlag::AllColumnsSearch ? treeWidget->columnCount() : 1;
 
@@ -141,7 +143,7 @@ void Utils::Gui::searchForTextInListWidget(QListWidget *listWidget, const QStrin
         listWidget->findItems("", Qt::MatchContains | Qt::MatchRecursive);
 
     // search text if at least one character was entered
-    if (text.count() >= 1) {
+    if (text.size() >= 1) {
         // hide all not found items
         Q_FOREACH (QListWidgetItem *item, allItems) {
             bool show = item->text().contains(text, Qt::CaseInsensitive);
@@ -584,7 +586,7 @@ bool Utils::Gui::autoFormatTableAtCursor(QPlainTextEdit *textEdit) {
 
         const QStringList &stringList = nextBlockText.split(QStringLiteral("|"));
         tableTextList.append(stringList);
-        endPosition = block.position() + nextBlockText.count();
+        endPosition = block.position() + nextBlockText.size();
         maxColumns = std::max(maxColumns, (int)stringList.count());
     }
 
@@ -617,7 +619,7 @@ bool Utils::Gui::autoFormatTableAtCursor(QPlainTextEdit *textEdit) {
                 continue;
             }
 
-            maxTextLength = std::max((int)text.count(), maxTextLength);
+            maxTextLength = std::max((int)text.size(), maxTextLength);
         }
 
         // a minimum of 3 headline separator characters are needed for
@@ -900,7 +902,7 @@ void Utils::Gui::restoreNoteTabs(QTabWidget *tabWidget, QVBoxLayout *layout) {
                 // create a new tab if there are too few tabs
                 if ((tabWidget->count() - 1) < i) {
                     auto *widgetPage = new QWidget();
-                    tabWidget->addTab(widgetPage, QStringLiteral(""));
+                    tabWidget->addTab(widgetPage, QLatin1String(""));
                 }
 
                 // set the current tab index and the note data
@@ -1003,6 +1005,10 @@ void Utils::Gui::setTreeWidgetItemToolTipForNote(QTreeWidgetItem *item, const No
         toolTipText += QObject::tr("<br />path: %1").arg(noteSubFolder.relativePath());
     }
 
+#ifdef QT_DEBUG
+    toolTipText += QStringLiteral("<br />id: %1").arg(note.getId());
+#endif
+
     item->setToolTip(0, toolTipText);
 
     // TODO: handle item widget too
@@ -1254,3 +1260,24 @@ QAction *Utils::Gui::findActionByData(QMenu *menu, const QVariant &data) {
     // Return nullptr if no matching action is found
     return nullptr;
 }
+
+void Utils::Gui::applyInterfaceStyle(QString interfaceStyle) {
+    if (interfaceStyle.isEmpty()) {
+        interfaceStyle = SettingsService().value(QStringLiteral("interfaceStyle")).toString();
+    }
+
+    // Apply custom style to hide menu icons
+    if (Utils::Misc::areMenuIconsHidden()) {
+        if (!interfaceStyle.isEmpty()) {
+            // Apply the selected interface style and the custom style
+            QStyle *interfaceStyleClass = QStyleFactory::create(interfaceStyle);
+            QApplication::setStyle(new NoMenuIconStyle(interfaceStyleClass));
+        } else {
+            // Apply the custom style only
+            QApplication::setStyle(new NoMenuIconStyle);
+        }
+    } else if (!interfaceStyle.isEmpty()) {
+        // Restore the interface style
+        QApplication::setStyle(interfaceStyle);
+    }
+}
